/*
 * Project name:
      Bluetooth Switch
 * Copyright:
      (c) mikroElektronika, 2015.
 * Description:
    - This project demonstrates wireless Bluetooth switch control, using
      clicker2 for STM32, Bluetooth click board and Android smart phone.
 * Test configuration:
     MCU:             STM32F407VG
                      http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/DM00037051.pdf
     Dev. Board:      Cliker2 for STM32
                      http://www.mikroe.com/stm32/clicker-2/
     Oscillator:      120000000 Hz
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
     Link:            http://www.mikroe.com/buggy/

 * NOTES:
    - Application for Android smart phone can be found on following link:
      https://play.google.com/store/search?q=ikroe&hl=en
*/

#define CR      0x0D
#define LF      0x0A

sbit LEDA at GPIOE_ODR.B12;
sbit LEDB at GPIOE_ODR.B15;
sbit BT_RST at GPIOE_ODR.B7;
sbit RELAY1 at GPIOD_ODR.B12;
sbit RELAY2 at GPIOE_ODR.B11;

char writeBuff[7];
char readBuff[24];
char data_len;
char data_ready;
char tmp;
char CONN_STATE = 0;
char RELAY2_state, RELAY1_state;

void UART2_Interrupt() iv IVT_INT_USART2 ics ICS_AUTO {
  tmp = UART2_Read();
  if (tmp == LF || tmp == CR) {
    readBuff[data_len] = 0;
    data_ready = 1;
  } else {
    readBuff[data_len] = tmp;
    data_len++;
  }
}

void MCU_Init() {
  GPIO_Digital_Output(&GPIOE_ODR, _GPIO_PINMASK_11 | _GPIO_PINMASK_12 | _GPIO_PINMASK_15 | _GPIO_PINMASK_7);
  GPIO_Digital_Output(&GPIOD_ODR, _GPIO_PINMASK_12);
  UART2_Init_Advanced(115200, _UART_8_BIT_DATA, _UART_NOPARITY, _UART_ONE_STOPBIT, &_GPIO_MODULE_USART2_PD56);
  delay_ms(200);
  data_ready = 0;
  data_len = 0;
  memset(readBuff, 0, 64);
  RXNEIE_USART2_CR1_bit = 1;
  NVIC_IntEnable(IVT_INT_USART2);
}

void main() {
  MCU_Init();
  BT_RST = 1;
  LEDA = 1;

  while (1) {
    if (data_ready) {
      if (strstr(readBuff, "GET")) {
        //Return raleys state
        writeBuff[0] = 83; //S
        writeBuff[1] = 69; //E
        writeBuff[2] = 84; //T
        writeBuff[3] = 61; //=
        writeBuff[4] = RELAY1_state + 48;
        writeBuff[5] = RELAY2_state + 48;
        writeBuff[6] = LF;
        UART2_Write_Text(&writeBuff);
      }
      
      if (strstr(readBuff, "RELAY1")) {
        if (readBuff[7] == 49) { //state 1
          RELAY1_state = 1;

        } else { //state 0
          RELAY1_state = 0;
        }
        RELAY1 = RELAY1_state;
      }

      if (strstr(readBuff, "RELAY2")) {
        if (readBuff[7] == 49) { //state 1
          RELAY2_state = 1;
        } else { //state 0
          RELAY2_state = 0;
        }
        RELAY2 = RELAY2_state;
      }
      //reset uart data
      memset(readBuff, 0, 24);
      data_ready = 0;
      data_len = 0;
    }
  }
}